Tutorials — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot Documentation contents »

# Tutorials

This section contains various tutorials that will help the reader get a feeling of Camelot. We assume that the reader has some knowledge of Python.

The reader can read the following sub-sections in any order.

- Creating a Movie Database Application
  - Starting a New Project
  - Main Window and Views
  - Creating the Movie Model
  - The EntityAdmin Subclass
  - Configuring the Application
  - Relationships
- Creating a Report with Camelot
  - Massaging the model
  - The Summary class
  - Using Jinja templates
- Add an import wizard to an application
  - Introduction
  - Create an action
  - Add the action to the GUI
  - Select the files
  - Create new movies
  - Refresh the GUI
  - Result
  - Unit tests
  - Conclusion

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot Documentation contents »

Comments
blog comments powered by Disqus